--------------------------------------------------------------------------------
-- Copyright (c) 2001 by Trenz Electronic.
-- Duenner Kirchweg 77, 32257 Buende, Germany, www.trenz-electronic.de
--------------------------------------------------------------------------------
-- Project:     TE-XC2S Application Note: System-on-Chip with USB
-- File:        xc2sFPGA.vhd
-- Description: FPGA top level.
-- History:     2001oct09, FB, Created.
--------------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;

entity xc2sFPGA is
	port(
		clk_a1 : in STD_LOGIC;
		init : in STD_LOGIC;
		ion_a5 : in STD_LOGIC;
		ion_b2 : in STD_LOGIC;
		iop_a5 : in STD_LOGIC;
		iop_b3 : in STD_LOGIC;
		ion_a1 : out STD_LOGIC;
		ion_a2 : out STD_LOGIC;
		ion_a3 : out STD_LOGIC;
		ion_a4 : out STD_LOGIC;
		ion_a6 : out STD_LOGIC;
		ion_b1 : out STD_LOGIC;
		ion_b3 : out STD_LOGIC;
		ion_b4 : out STD_LOGIC;
		ion_b5 : out STD_LOGIC;
		ion_b6 : out STD_LOGIC;
		iop_a1 : out STD_LOGIC;
		iop_a2 : out STD_LOGIC;
		iop_a3 : out STD_LOGIC;
		iop_a4 : out STD_LOGIC;
		iop_a6 : out STD_LOGIC;
		iop_b1 : out STD_LOGIC;
		iop_b2 : out STD_LOGIC;
		iop_b4 : out STD_LOGIC;
		iop_b5 : out STD_LOGIC;
		iop_b6 : out STD_LOGIC
		);
	
	-- entity declarations --
	attribute LOC: string;
	attribute LOC of clk_a1: signal is "P185";
	attribute LOC of iop_a1: signal is "P191";
	attribute LOC of ion_a1: signal is "P192";
	attribute LOC of iop_a2: signal is "P193";
	attribute LOC of ion_a2: signal is "P194";
	attribute LOC of iop_a3: signal is "P195";
	attribute LOC of ion_a3: signal is "P199";
	attribute LOC of iop_a4: signal is "P200";
	attribute LOC of ion_a4: signal is "P201";
	attribute LOC of iop_a5: signal is "P202";
	attribute LOC of ion_a5: signal is "P203";
	attribute LOC of iop_a6: signal is "P204";
	attribute LOC of ion_a6: signal is "P205";
	attribute LOC of iop_b1: signal is "P4";
	attribute LOC of ion_b1: signal is "P5";
	attribute LOC of iop_b2: signal is "P6";
	attribute LOC of ion_b2: signal is "P7";
	attribute LOC of iop_b3: signal is "P8";
	attribute LOC of ion_b3: signal is "P9";
	attribute LOC of iop_b4: signal is "P10";
	attribute LOC of ion_b4: signal is "P14";
	attribute LOC of iop_b5: signal is "P15";
	attribute LOC of ion_b5: signal is "P16";
	attribute LOC of iop_b6: signal is "P17";
	attribute LOC of ion_b6: signal is "P18";
	attribute LOC of init: signal is "P107";
end xc2sFPGA;

architecture BHV of xc2sFPGA is
	
	---- Component declarations -----
	
	component teBL
		port (
			DISP : in STD_LOGIC_VECTOR (15 downto 0);
			LED : in STD_LOGIC_VECTOR (7 downto 0);
			clk_a1 : in STD_LOGIC;
			ion_a5 : in STD_LOGIC;
			ion_b2 : in STD_LOGIC;
			iop_a5 : in STD_LOGIC;
			iop_b3 : in STD_LOGIC;
			utx0 : in STD_LOGIC;
			utxd : in STD_LOGIC;
			utxoe : in STD_LOGIC;
			vb : in STD_LOGIC;
			vg : in STD_LOGIC;
			vi : in STD_LOGIC;
			vr : in STD_LOGIC;
			CLK25 : out STD_LOGIC;
			CLK48 : out STD_LOGIC;
			PB : out STD_LOGIC_VECTOR (7 downto 0);
			SW : out STD_LOGIC_VECTOR (7 downto 0);
			ion_a1 : out STD_LOGIC;
			ion_a2 : out STD_LOGIC;
			ion_a3 : out STD_LOGIC;
			ion_a4 : out STD_LOGIC;
			ion_a6 : out STD_LOGIC;
			ion_b1 : out STD_LOGIC;
			ion_b3 : out STD_LOGIC;
			ion_b4 : out STD_LOGIC;
			ion_b5 : out STD_LOGIC;
			ion_b6 : out STD_LOGIC;
			iop_a1 : out STD_LOGIC;
			iop_a2 : out STD_LOGIC;
			iop_a3 : out STD_LOGIC;
			iop_a4 : out STD_LOGIC;
			iop_a6 : out STD_LOGIC;
			iop_b1 : out STD_LOGIC;
			iop_b2 : out STD_LOGIC;
			iop_b4 : out STD_LOGIC;
			iop_b5 : out STD_LOGIC;
			iop_b6 : out STD_LOGIC;
			urx0 : out STD_LOGIC;
			urxd : out STD_LOGIC;
			vcol : out STD_LOGIC_VECTOR (9 downto 0);
			vhblk : out STD_LOGIC;
			vrow : out STD_LOGIC_VECTOR (9 downto 0);
			vvblk : out STD_LOGIC
			);
	end component;
	component xc2sCore
		port (
			clk48 : in STD_LOGIC;
			rst : in STD_LOGIC;
			urx0 : in STD_LOGIC;
			urxd : in STD_LOGIC;
			disp : out STD_LOGIC_VECTOR (15 downto 0);
			utx0 : out STD_LOGIC;
			utxd : out STD_LOGIC;
			utxoe : out STD_LOGIC
			);
	end component;
	
	----     Constants     -----
	constant DANGLING_INPUT_CONSTANT : STD_LOGIC := 'Z';
	
	---- Signal declarations used on the diagram ----
	
	signal BUS3894 : STD_LOGIC_VECTOR (15 downto 0);
	signal NET3874 : STD_LOGIC;
	signal NET3878 : STD_LOGIC;
	signal NET3882 : STD_LOGIC;
	signal NET3886 : STD_LOGIC;
	signal NET3890 : STD_LOGIC;
	signal NET3898 : STD_LOGIC;
	
	---- Global signals declarations -----
	signal RST : STD_LOGIC;
	
	
	---- Declaration for Dangling input ----
	signal Dangling_Input_Signal : STD_LOGIC;
	
begin
	
	---- User defined VHDL code ----
	
	----- Statement0 ----
	rst<= not(init);
	
	----  Component instantiations  ----
	
	Ubl : teBL
	port map(
		CLK48 => NET3898,
		DISP => BUS3894,
		LED(0) => Dangling_Input_Signal,
		LED(1) => Dangling_Input_Signal,
		LED(2) => Dangling_Input_Signal,
		LED(3) => Dangling_Input_Signal,
		LED(4) => Dangling_Input_Signal,
		LED(5) => Dangling_Input_Signal,
		LED(6) => Dangling_Input_Signal,
		LED(7) => Dangling_Input_Signal,
		clk_a1 => clk_a1,
		ion_a1 => ion_a1,
		ion_a2 => ion_a2,
		ion_a3 => ion_a3,
		ion_a4 => ion_a4,
		ion_a5 => ion_a5,
		ion_a6 => ion_a6,
		ion_b1 => ion_b1,
		ion_b2 => ion_b2,
		ion_b3 => ion_b3,
		ion_b4 => ion_b4,
		ion_b5 => ion_b5,
		ion_b6 => ion_b6,
		iop_a1 => iop_a1,
		iop_a2 => iop_a2,
		iop_a3 => iop_a3,
		iop_a4 => iop_a4,
		iop_a5 => iop_a5,
		iop_a6 => iop_a6,
		iop_b1 => iop_b1,
		iop_b2 => iop_b2,
		iop_b3 => iop_b3,
		iop_b4 => iop_b4,
		iop_b5 => iop_b5,
		iop_b6 => iop_b6,
		urx0 => NET3878,
		urxd => NET3874,
		utx0 => NET3886,
		utxd => NET3882,
		utxoe => NET3890,
		vb => Dangling_Input_Signal,
		vg => Dangling_Input_Signal,
		vi => Dangling_Input_Signal,
		vr => Dangling_Input_Signal
		);
	
	Ucore : xc2sCore
	port map(
		clk48 => NET3898,
		disp => BUS3894,
		rst => rst,
		urx0 => NET3878,
		urxd => NET3874,
		utx0 => NET3886,
		utxd => NET3882,
		utxoe => NET3890
		);
	
	
	---- Dangling input signal assignment ----
	
	Dangling_Input_Signal <= DANGLING_INPUT_CONSTANT;
	
end BHV;

--------------------------------------------------------------------------------
-- end of file
